@@ -3,6 +3,7 @@ import soco
 import argparse
 import os
 import sys
+from signal import signal, SIGINT
 import pprint
 import time
 
@@ -22,6 +23,11 @@ def error_and_exit(msg):
     os._exit(1)
 
 
+def handler(signal_received, frame):
+    # Exit silently without stack dump
+    exit(0)
+
+
 def get_speaker(name, local=False):
     # Allow the use of an IP address even if 'local' is specified
     if speakers.Speakers.is_ipv4_address(name):
@@ -32,7 +38,15 @@ def get_speaker(name, local=False):
         return soco.discovery.by_name(name)
 
 
+def version():
+    print("soco-cli version: {}".format(__version__))
+    print("soco version:     {}".format(soco.__version__))
+
+
 def main():
+    # Handle SIGINT
+    signal(SIGINT, handler)
+
     # Create the argument parser
     parser = argparse.ArgumentParser(
         prog="sonos",
@@ -84,8 +98,7 @@ def main():
     args = parser.parse_args()
 
     if args.version:
-        print("soco-cli version: {}".format(__version__))
-        print("soco version:     {}".format(soco.__version__))
+        version()
         exit(0)
 
     use_local_speaker_list = args.use_local_speaker_list
@@ -129,20 +142,21 @@ def main():
             # Special case of a "wait" command
             # Assume there aren't any speakers called 'wait':
             if speaker_name in ["wait"]:
+                duration = 0
                 try:
                     if action.endswith("s"):  # Seconds (explicit)
                         duration = float(action[:-1])
-                    elif action.endswith("m"):  # Minutes not seconds
+                    elif action.endswith("m"):  # Minutes
                         duration = float(action[:-1]) * 60
-                    elif action.endswith("h"):  # Hours not seconds
+                    elif action.endswith("h"):  # Hours
                         duration = float(action[:-1]) * 60 * 60
-                    else:
+                    else:  # Seconds (default)
                         duration = float(action)
-                    time.sleep(duration)
                 except:
                     error_and_exit(
                         "'wait' requires integer number of seconds, or float number of minutes + 'm'"
                     )
+                time.sleep(duration)
                 continue
             args = sequence[2:]
             speaker = get_speaker(speaker_name, use_local_speaker_list)
